@@ -4,7 +4,7 @@ See LICENSE file.
 """
 
 
-from pyqtgraph import QtGui
+from pyqtgraph import QtCore, QtGui
 
 from imageanalysis.structures import Scan
 from imageanalysis.ui.data_view.gridded_data import GriddedDataWidget
@@ -19,14 +19,17 @@ class DataView(QtGui.QTabWidget):
 
         self.scan_list = []
         self.setTabsClosable(True)
-        self.tabCloseRequested.connect(self.closeTab)
+        self.tabCloseRequested.connect(self._closeTab)
 
-    def addScan(self, scan: Scan) -> None:
+    def _addScan(self, scan: Scan) -> None:
         """Adds new DataViewTab."""
-        self.addTab(DataViewTab(scan), str(scan.number))
 
-    def closeTab(self, index: int) -> None:
+        tab_title = str(scan.number)
+        self.addTab(DataViewTab(scan=scan), tab_title)
+
+    def _closeTab(self, index: int) -> None:
         """Closes DataViewTab at specific index."""
+        
         w = self.widget(index)
         w.deleteLater()
         self.removeTab(index)
@@ -38,12 +41,14 @@ class DataViewTab(QtGui.QWidget):
     def __init__(self, scan: Scan) -> None:
         super(DataViewTab, self).__init__()
 
+        self.setAttribute(QtCore.Qt.WA_DeleteOnClose)
+        
         self.scan = scan
 
         # Child widgets
         self.tab_widget = QtGui.QTabWidget()
-        self.tab_widget.addTab(RawDataWidget(scan), "Raw")
-        self.tab_widget.addTab(GriddedDataWidget(scan), "Gridded")
+        self.tab_widget.addTab(RawDataWidget(scan=scan), "Raw")
+        self.tab_widget.addTab(GriddedDataWidget(scan=scan), "Gridded")
 
         # Layout
         self.layout = QtGui.QGridLayout()
