@@ -4,12 +4,11 @@ See LICENSE file.
 """
 
 
-import numpy as np
 from pyqtgraph import QtGui
 
 from imageanalysis.io import \
     isValidProjectPath, getSPECPaths, getXMLPaths
-from imageanalysis.structures import Project
+from imageanalysis.structures import Project, Scan
 
 
 class ProjectSelectionWidget(QtGui.QWidget):
@@ -60,19 +59,19 @@ class ProjectSelectionWidget(QtGui.QWidget):
         self.layout.addWidget(self.project_files_gbx, 1, 0, 1, 2)
 
         # Connections
-        self.project_btn.clicked.connect(self.selectProject)
+        self.project_btn.clicked.connect(self._selectProject)
         self.spec_cbx.currentTextChanged.connect(
-            self.enableLoadProjectButton
+            self._enableLoadProjectButton
         )
         self.instrument_cbx.currentTextChanged.connect(
-            self.enableLoadProjectButton
+            self._enableLoadProjectButton
         )
         self.detector_cbx.currentTextChanged.connect(
-            self.enableLoadProjectButton
+            self._enableLoadProjectButton
         )
-        self.load_project_btn.clicked.connect(self.loadProject)
+        self.load_project_btn.clicked.connect(self._loadProject)
 
-    def selectProject(self) -> None:
+    def _selectProject(self) -> None:
         """Allows user to select a project directory."""
 
         project_path = QtGui.QFileDialog.getExistingDirectory(
@@ -86,7 +85,7 @@ class ProjectSelectionWidget(QtGui.QWidget):
                 self.project_path = project_path
                 self.project_txt.setText(project_path)
                 self.project_files_gbx.setEnabled(True)
-                self.populateProjectFilesGroupbox()
+                self._populateProjectFilesGroupbox()
             else:
                 self.project_files_gbx.setEnabled(False)
                 msg = QtGui.QMessageBox()
@@ -95,7 +94,7 @@ class ProjectSelectionWidget(QtGui.QWidget):
                 msg.setText("Invalid project directory.")
                 msg.exec_()
 
-    def populateProjectFilesGroupbox(self) -> None:
+    def _populateProjectFilesGroupbox(self) -> None:
         """Adds SPEC files and XML files to comboboxes."""
 
         self.spec_cbx.clear()
@@ -109,8 +108,8 @@ class ProjectSelectionWidget(QtGui.QWidget):
         self.instrument_cbx.addItems(xml_paths)
         self.detector_cbx.addItems(xml_paths)
 
-    def enableLoadProjectButton(self) -> None:
-        """Enables "Load Project" button."""
+    def _enableLoadProjectButton(self) -> None:
+        """Sets path variables and enables 'Load Project' button."""
 
         self.spec_path = f"{self.project_path}/" \
             f"{self.spec_cbx.currentText()}"
@@ -121,27 +120,18 @@ class ProjectSelectionWidget(QtGui.QWidget):
 
         self.load_project_btn.setEnabled(True)
 
-    def loadProject(self) -> None:
+    def _loadProject(self) -> None:
         """Creates and loads Project object."""
 
         # Attempts to create and load Project with given file paths
-        try:
-            self.project = Project(
-                project_path=self.project_path,
-                spec_path=self.spec_path,
-                instrument_path=self.instrument_path,
-                detector_path=self.detector_path
-            )
-            # Loads project scans
-            self.main_window.scan_selection_widget.loadProjectScanList(
-                self.project
-            )
-        except Exception as ex:
-            msg = QtGui.QMessageBox()
-            msg.setIcon(QtGui.QMessageBox.Critical)
-            msg.setWindowTitle("Error")
-            msg.setText(ex.args[-1])
-            msg.exec_()
+        project = Project(
+            project_path=self.project_path,
+            spec_path=self.spec_path,
+            instrument_path=self.instrument_path,
+            detector_path=self.detector_path
+        )
+        self.project = project
+        self.main_window.scan_selection_widget._loadProject(project=project)
 
 
 class ScanSelectionWidget(QtGui.QWidget):
@@ -155,9 +145,6 @@ class ScanSelectionWidget(QtGui.QWidget):
         # Project
         self.project = None
 
-        # Scans that have been previewed
-        self.previewed_scans = []
-
         # Child widgets
         self.scan_lstw = QtGui.QListWidget()
         self.scan_details_gbx = QtGui.QGroupBox()
@@ -254,107 +241,100 @@ class ScanSelectionWidget(QtGui.QWidget):
         self.layout.setRowStretch(1, 2)
 
         # Connections
-        self.scan_lstw.itemClicked.connect(self.previewScan)
-        self.reset_btn.clicked.connect(self.resetGriddingOptions)
-        self.load_scan_btn.clicked.connect(self.loadScan)
-
-    def loadProjectScanList(self, project) -> None:
-        """Populates scan list."""
+        self.scan_lstw.itemClicked.connect(self._previewScan)
+        self.reset_btn.clicked.connect(self._resetScanGridParameters)
+        self.load_scan_btn.clicked.connect(self._loadScan)
 
+    def _loadProject(self, project: Project) -> None:
+        """Sets project variable and loads scan numbers in list."""
         self.project = project
         self.scan_lstw.clear()
-        self.scan_lstw.addItems(self.project.scan_numbers)
+        self.scan_lstw.addItems(self.project.getScanNumbers())
 
-    def clearProjectScanList(self) -> None:
-        """Clears scan list."""
+    def _getCurrentScan(self) -> Scan:
+        """Returns Scan object of currently highlighted scan number."""
+        scan_number = int(self.scan_lstw.currentItem().text())
+        scan = self.project.getScan(scan_number)
+        return scan
 
-        self.scan_lstw.clear()
+    def _previewScan(self, scan=None) -> None:
+        """Displays preview information for a Scan object."""
+        self.scan_details_gbx.setEnabled(True)
 
-    def previewScan(self) -> None:
-        """Displays preview information for currently selected scan."""
+        scan = self._getCurrentScan()
 
-        # Retrieve current scan
-        i = self.scan_lstw.currentRow()
-        scan = self.project.scans[i]
-
-        # Loads RSM and raw image data if not previously previewed
-        if scan not in self.previewed_scans:
-            self.project.scans[i].raw_image_data = scan.getImageData()
-            self.project.scans[i].mapImageData()
-            self.previewed_scans.append(scan)
-
-        # Scan header details from SPEC
+        # Scan metadata
         header = scan.spec_scan.S.split()
         number = header[0]
         type = f"{header[1]} {header[2]}"
         bounds = f"({header[3]}, {header[4]})"
         point_count = str(len(scan.spec_scan.data_lines))
         date = scan.spec_scan.date
-
-        # Displays scan details in child widgets
         self.scan_number_txt.setText(number)
         self.scan_point_count_txt.setText(point_count)
         self.scan_date_lbl.setText(date)
         self.scan_type_lbl.setText(type)
         self.scan_bounds_lbl.setText(bounds)
-        self.h_min_sbx.setValue(round(scan.h_grid_min, 3))
-        self.h_max_sbx.setValue(round(scan.h_grid_max, 3))
-        self.h_n_sbx.setValue(scan.h_grid_n)
-        self.k_min_sbx.setValue(round(scan.k_grid_min, 3))
-        self.k_max_sbx.setValue(round(scan.k_grid_max, 3))
-        self.k_n_sbx.setValue(scan.k_grid_n)
-        self.l_min_sbx.setValue(round(scan.l_grid_min, 3))
-        self.l_max_sbx.setValue(round(scan.l_grid_max, 3))
-        self.l_n_sbx.setValue(scan.l_grid_n)
 
-        self.scan_details_gbx.setEnabled(True)
+        # Scan grid parameters
+        if scan.rsm is None:
+            scan._mapRawImageData()
+        h_min = scan.grid_parameters["H"]["min"]
+        k_min = scan.grid_parameters["K"]["min"]
+        l_min = scan.grid_parameters["L"]["min"]
+        h_max = scan.grid_parameters["H"]["max"]
+        k_max = scan.grid_parameters["K"]["max"]
+        l_max = scan.grid_parameters["L"]["max"]
+        h_n = scan.grid_parameters["H"]["n"]
+        k_n = scan.grid_parameters["K"]["n"]
+        l_n = scan.grid_parameters["L"]["n"]
+        self.h_min_sbx.setValue(h_min)
+        self.h_max_sbx.setValue(h_max)
+        self.h_n_sbx.setValue(h_n)
+        self.k_min_sbx.setValue(k_min)
+        self.k_max_sbx.setValue(k_max)
+        self.k_n_sbx.setValue(k_n)
+        self.l_min_sbx.setValue(l_min)
+        self.l_max_sbx.setValue(l_max)
+        self.l_n_sbx.setValue(l_n)
 
-    def resetGriddingOptions(self) -> None:
-        """Resets gridding parameters to default values for scan."""
+    def _resetScanGridParameters(self) -> None:
+        """Resets grid parameters for a scan object."""
+        scan = self._getCurrentScan()
+        scan._resetGridParameters()
+        self._previewScan()
 
-        # Retrieves current scan
-        i = self.scan_lstw.currentRow()
-        scan = self.project.scans[i]
-
-        gridding_options_sbxs = [
-            self.h_min_sbx, self.h_max_sbx, self.h_n_sbx,
-            self.k_min_sbx, self.k_max_sbx, self.k_n_sbx,
-            self.l_min_sbx, self.l_max_sbx, self.l_n_sbx,
-        ]
-        original_params = [
-            np.amin(scan.h_map), np.amax(scan.h_map), 250,
-            np.amin(scan.k_map), np.amax(scan.k_map), 250,
-            np.amin(scan.l_map), np.amax(scan.l_map), 250,
-        ]
-
-        for sbx, o_param in zip(gridding_options_sbxs, original_params):
-            sbx.setValue(round(o_param, 3))
-
-        # Enable "Load Scan" button
-        self.load_scan_btn.setEnabled(True)
-
-    def loadScan(self) -> None:
-        """Loads scan data into a new DataView tab."""
-
-        # Retrieves current scan
-        i = self.scan_lstw.currentRow()
-        scan = self.project.scans[i]
-
-        sbxs = [
-            self.h_min_sbx, self.h_max_sbx, self.h_n_sbx,
-            self.k_min_sbx, self.k_max_sbx, self.k_n_sbx,
-            self.l_min_sbx, self.l_max_sbx, self.l_n_sbx,
-        ]
-
-        # Checks if spinbox mins/maxes are valid
+    def _loadScan(self) -> None:
+        """Prepares and loads a Scan into the DataView."""
         if (
-            sbxs[0].value() < sbxs[1].value() and
-            sbxs[3].value() < sbxs[4].value() and
-            sbxs[6].value() < sbxs[7].value()
+            self.h_min_sbx.value() < self.h_max_sbx.value() and
+            self.k_min_sbx.value() < self.k_max_sbx.value() and
+            self.l_min_sbx.value() < self.l_max_sbx.value()
         ):
-            scan.setGriddingParameters(*(float(sbx.value()) for sbx in sbxs))
-            scan.gridImageData()
-            self.main_window.data_view.addScan(scan)
+            grid_params = {
+                "H": {
+                    "min": self.h_min_sbx.value(),
+                    "max": self.h_max_sbx.value(),
+                    "n": self.h_n_sbx.value()
+                },
+                "K": {
+                    "min": self.k_min_sbx.value(),
+                    "max": self.k_max_sbx.value(),
+                    "n": self.k_n_sbx.value()
+                },
+                "L": {
+                    "min": self.l_min_sbx.value(),
+                    "max": self.l_max_sbx.value(),
+                    "n": self.l_n_sbx.value()
+                }
+            }
+
+            scan = self._getCurrentScan()
+            scan._setGridParameters(params=grid_params)
+
+            scan._loadRawImageData()
+            scan._gridRawImageData()
+            self.main_window.data_view._addScan(scan=scan)
         else:
             msg = QtGui.QMessageBox()
             msg.setIcon(QtGui.QMessageBox.Critical)
